@@ -223,22 +223,18 @@ void Job::onUserQuery(Query *query)
 
 bool Job::doKill()
 {
-    const bool canKillJob = archiveInterface()->doKill();
-
-    if (!d->isRunning()) {
-        return canKillJob;
-    }
-
-    d->requestInterruption();
-
-    if (!canKillJob) {
-        qCDebug(ARK) << "Forcing thread exit in one second...";
-        d->wait(1000);
+    const bool killed = archiveInterface()->doKill();
+    if (killed) {
         return true;
     }
 
-    d->wait();
-    return canKillJob;
+    if (d->isRunning()) {
+        qCDebug(ARK) << "Requesting graceful thread interruption, will abort in one second otherwise.";
+        d->requestInterruption();
+        d->wait(1000);
+    }
+
+    return true;
 }
 
 LoadJob::LoadJob(Archive *archive, ReadOnlyArchiveInterface *interface)
@@ -644,7 +640,7 @@ void AddJob::doWork()
     uint totalCount = 0;
     QElapsedTimer timer;
     timer.start();
-    foreach (const Archive::Entry* entry, m_entries) {
+    for (const Archive::Entry* entry : qAsConst(m_entries)) {
         totalCount++;
         if (QFileInfo(entry->fullPath()).isDir()) {
             QDirIterator it(entry->fullPath(), QDir::AllEntries | QDir::Readable | QDir::Hidden | QDir::NoDotAndDotDot, QDirIterator::Subdirectories);
@@ -666,7 +662,7 @@ void AddJob::doWork()
     Q_ASSERT(m_writeInterface);
 
     // The file paths must be relative to GlobalWorkDir.
-    foreach (Archive::Entry *entry, m_entries) {
+    for (Archive::Entry *entry : qAsConst(m_entries)) {
         // #191821: workDir must be used instead of QDir::current()
         //          so that symlinks aren't resolved automatically
         const QString &fullPath = entry->fullPath();
